use super::*;
use maud::{html, Markup, Render};

impl Render for Ident
{
    fn render(&self) -> Markup
    {
	html! {
	    b.ident {
		@if let Some(email) = self.email() {
		    a href=(format!("mailto:{}", email)) { (self.name()) }
		} @else {
		    (self.name())
		}
		@if let Some(tripcode) = self.tripcode() {
		    " "
			code {
			    "!" (tripcode)
			}
		}
	    }
	}
    }
}

impl Render for Post
{
    fn render(&self) -> Markup
    {
	let id = self.post_id_mnemonic();
	html! {
	    article#(id) {
		header {
		    (self.ident)
			" "
			time datetime=(self.created()) {
			    (self.created()) //TODO format the DateTime properly
			}
		    nav {
			a href=(format!("#{}", id)) { "No." }
			a href=(format!("#q_{}", id)) { (id) }
		    }
		}
		blockquote {
		    (self.body())
		}
		//TODO: Signature and hash and other things
	    }
	}
    }
}

#[cfg(test)]
mod tests
{
    #[test]
    fn ident_htmlrender()
    {
	let ident = super::Ident::new(Some("Name"), Some(crate::mnemonic::Tripcode::generate("mwee").unwrap()), Some("user@example.com"));
	use maud::Render;
	
	assert_eq!(r#"<b class="ident"><a href="mailto:user@example.com">Name</a> <code>!えナセッゲよラで</code></b>"#, &ident.render().into_string());
    }
}
